skhubness.neighbors.HNSW — scikit-hubness 0.21a1 documentation

# skhubness.neighbors.HNSW

class `skhubness.neighbors.` `HNSW`(n_candidates: int = 5, metric: str = 'euclidean', method: str = 'hnsw', post_processing: int = 2, n_jobs: int = 1, verbose: int = 0)
  `__init__`(self, n_candidates: 'int' = 5, metric: 'str' = 'euclidean', method: 'str' = 'hnsw', post_processing: 'int' = 2, n_jobs: 'int' = 1, verbose: 'int' = 0)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(self, n_candidates, metric, method, …) | Initialize self.
  `fit`(self, X[, y]) | Setup the HNSW index.
  `kneighbors`(self, X, n_candidates, …) |

  Attributes

  `valid_metrics` |

  `fit`(self, X, y=None) → 'HNSW'

    Setup the HNSW index.